@@ -29,20 +29,20 @@ if sys.version_info[0] < 3:  # pragma: no cover
     import SocketServer as socketserver
     string_types = basestring,  # noqa
     input_ = raw_input  # noqa
-else:
+else:  # pragma: no cover
     import queue
     import socketserver
     string_types = str
     input_ = input
 
 
-__version__ = '0.1.4'
+__version__ = '0.2.0'
 __author__ = 'pahaz'
 
 
 DEFAULT_LOGLEVEL = logging.ERROR  #: default level if no logger passed (ERROR)
 TUNNEL_TIMEOUT = 1.0  #: Timeout (seconds) for tunnel connection
-DAEMON = False
+_DAEMON = False  #: Use daemon threads in connections
 TRACE_LEVEL = 1
 _CONNECTION_COUNTER = 1
 _LOCK = threading.Lock()
@@ -314,7 +314,7 @@ class _ForwardHandler(socketserver.BaseRequestHandler):
                                     self.remote_address,
                                     hexlify(data)
                                 ))
-                chan.send(data)
+                chan.sendall(data)
             if chan in rqst:  # else
                 if not chan.recv_ready():
                     break
@@ -323,7 +323,7 @@ class _ForwardHandler(socketserver.BaseRequestHandler):
                     TRACE_LEVEL,
                     '<<< IN {0} recv: {1} <<<'.format(self.info, hexlify(data))
                 )
-                self.request.send(data)
+                self.request.sendall(data)
 
     def handle(self):
         uid = get_connection_id()
@@ -415,7 +415,7 @@ class _ThreadingForwardServer(socketserver.ThreadingMixIn, _ForwardServer):
     Allow concurrent connections to each tunnel
     """
     # If True, cleanly stop threads created by ThreadingMixIn when quitting
-    daemon_threads = DAEMON
+    daemon_threads = _DAEMON
 
 
 class _UnixStreamForwardServer(UnixStreamServer):
@@ -459,7 +459,7 @@ class _ThreadingUnixStreamForwardServer(socketserver.ThreadingMixIn,
     Allow concurrent connections to each tunnel
     """
     # If True, cleanly stop threads created by ThreadingMixIn when quitting
-    daemon_threads = DAEMON
+    daemon_threads = _DAEMON
 
 
 class SSHTunnelForwarder(object):
@@ -614,9 +614,8 @@ class SSHTunnelForwarder(object):
 
         host_pkey_directories (list):
             Look for pkeys in folders on this list, for example ['~/.ssh'].
-            An empty list disables this feature
 
-            Default: ``None``
+            Default: ``None`` (disabled)
 
             .. versionadded:: 0.1.4
 
@@ -720,8 +719,8 @@ class SSHTunnelForwarder(object):
 
     """
     skip_tunnel_checkup = True
-    daemon_forward_servers = DAEMON  #: flag tunnel threads in daemon mode
-    daemon_transport = DAEMON  #: flag SSH transport thread in daemon mode
+    daemon_forward_servers = _DAEMON  #: flag tunnel threads in daemon mode
+    daemon_transport = _DAEMON  #: flag SSH transport thread in daemon mode
 
     def local_is_up(self, target):
         """
@@ -1090,7 +1089,7 @@ class SSHTunnelForwarder(object):
                 logger.warning('Private key file not found: {0}'
                                .format(ssh_pkey))
         if isinstance(ssh_pkey, paramiko.pkey.PKey):
-            ssh_loaded_pkeys.append(ssh_pkey)
+            ssh_loaded_pkeys.insert(0, ssh_pkey)
 
         if not ssh_password and not ssh_loaded_pkeys:
             raise ValueError('No password or public key available!')
@@ -1112,11 +1111,13 @@ class SSHTunnelForwarder(object):
             self.logger.debug('Connecting via proxy: {0}'.format(proxy_repr))
             _socket = self.ssh_proxy
         else:
-            _socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            _socket = (self.ssh_host, self.ssh_port)
         if isinstance(_socket, socket.socket):
             _socket.settimeout(SSH_TIMEOUT)
             _socket.connect((self.ssh_host, self.ssh_port))
         transport = paramiko.Transport(_socket)
+        if isinstance(transport.sock, socket.socket):
+            transport.sock.settimeout(SSH_TIMEOUT)
         transport.set_keepalive(self.set_keepalive)
         transport.use_compression(compress=self.compression)
         transport.daemon = self.daemon_transport
@@ -1533,7 +1534,7 @@ class SSHTunnelForwarder(object):
             self.ssh_proxy.cmd[1] if self.ssh_proxy else 'no',
             self.ssh_username,
             credentials,
-            self.ssh_host_key if self.ssh_host_key else'not checked',
+            self.ssh_host_key if self.ssh_host_key else 'not checked',
             '' if self.is_alive else 'not ',
             'disabled' if not self.set_keepalive else
             'every {0} sec'.format(self.set_keepalive),
@@ -1580,6 +1581,12 @@ def open_tunnel(*args, **kwargs):
 
             .. versionadded:: 0.1.0
 
+        block_on_close (boolean):
+            Wait until all connections are done during close by changing the
+            value of :attr:`~SSHTunnelForwarder.block_on_close`
+
+            Default: True
+
     .. note::
         A value of ``debug_level`` set to 1 == ``TRACE`` enables tracing mode
     .. note::
@@ -1615,8 +1622,9 @@ def open_tunnel(*args, **kwargs):
             kwargs
         )
 
-    ssh_port = kwargs.pop('ssh_port', None)
+    ssh_port = kwargs.pop('ssh_port', 22)
     skip_tunnel_checkup = kwargs.pop('skip_tunnel_checkup', True)
+    block_on_close = kwargs.pop('block_on_close', _DAEMON)
     if not args:
         if isinstance(ssh_address_or_host, tuple):
             args = (ssh_address_or_host, )
@@ -1624,6 +1632,8 @@ def open_tunnel(*args, **kwargs):
             args = ((ssh_address_or_host, ssh_port), )
     forwarder = SSHTunnelForwarder(*args, **kwargs)
     forwarder.skip_tunnel_checkup = skip_tunnel_checkup
+    forwarder.daemon_forward_servers = not block_on_close
+    forwarder.daemon_transport = not block_on_close
     return forwarder
 
 
